#!/bin/sh

################################################################################
# This script is used to start the game                                        #
################################################################################

# Barricade installation directory (where are the binaries)
BARRICADE_DIR="Installation directory not found"
# Java command (that should be in the path)
JAVA="java"

################################################################################
# Locate the script directory, from wherever or however this script is called
# This set the global variable BARRICADE_DIR
################################################################################
getScriptDirectory() {
	# $0 is never overwritten (by function parameters) in functions, as first function parameter is $1
	# So we could use $0 drectly and not use the first function parameter here, but to be less confusing
	# we prefer being explicit here, using $1 and a function parameter instead...
	BARRICADE_DIR=`dirname $1`
}

# Locate the script directory and thus the installation directory
getScriptDirectory $0
echo
echo "### Using the following installation directory:"
echo ${BARRICADE_DIR}

################################################################################
# Check that java is available through the path and that it has the minimum
# required version
################################################################################

checkJava() {
	# Minimum required java version
	REQUIRED_VERSION=1.5
	# Java download URL
	JAVA_DL_URL="http://www.java.com"

	# Localized messages

	FR_NEED_SUITABLE_JAVA="Java n'est pas installe ou n'a pas une version suffisante ou n'est pas dans votre PATH. Vous devez installer une version gratuite de Java au moins egale a ${REQUIRED_VERSION}. Pour en telecharger une, rendez-vous a l'adresse ${JAVA_DL_URL}"

	EN_NEED_SUITABLE_JAVA="Java is not installed or has not the right version or is not in your PATH. You need to install a free Java runtime environment with version ${REQUIRED_VERSION} or higher. To download such a version, please go to ${JAVA_DL_URL}"

	# Get locale to localize messages
	LOCALE=`locale | grep LANG= | cut -d"=" -f2 | cut -d"_" -f1`
	case ${LOCALE} in
	  "fr")
	    NEED_SUITABLE_JAVA=${FR_NEED_SUITABLE_JAVA}
	    ;;
	  "FR")
	    NEED_SUITABLE_JAVA=${FR_NEED_SUITABLE_JAVA}
	    ;;
	  "en")
	    NEED_SUITABLE_JAVA=${EN_NEED_SUITABLE_JAVA}
	    ;;
	  "EN")
	    NEED_SUITABLE_JAVA=${EN_NEED_SUITABLE_JAVA}
	    ;;
	  *)
	    NEED_SUITABLE_JAVA=${EN_NEED_SUITABLE_JAVA}
	    ;;
	esac

	# Transform the required version string into a number that can be used in comparisons e.g: 1.5 gives 105
	REQUIRED_VERSION=`echo ${REQUIRED_VERSION} | sed -e 's;\.;0;g'`

	# Check java version
	rm -f /tmp/tmp.ver
	${JAVA} -version 2> /tmp/tmp.ver

	# Is java in the path ?
	EXIT_CODE=$?
	if test ${EXIT_CODE} -ne 0
	then
	  echo
	  echo "${NEED_SUITABLE_JAVA}"
	  echo
	  exit 1
	fi

	# Check version output
	TMP_VERSION=`cat /tmp/tmp.ver | grep "java version" | awk '{ print substr($3, 2, length($3)-2); }'`
	rm -f /tmp/tmp.ver
	VERSION=`echo ${TMP_VERSION} | awk '{ print substr($1, 1, 3); }' | sed -e 's;\.;0;g'`
	if [ ${VERSION} ]
	then
		if [ ${VERSION} -lt ${REQUIRED_VERSION} ]
		then
			# Too old java version
		    echo
			echo ${NEED_SUITABLE_JAVA}
		    echo
			exit 1
		fi
	else
	    # No java found
		echo
	  	echo ${NEED_SUITABLE_JAVA}
		echo
		exit 1
	fi
}

# Check for suitable installed java version
checkJava

################################################################################
# Script configuration variables                                               #
################################################################################

# Barricade jar
BARRICADE_JAR="barricade.jar"

################################################################################
# Start the game                                                               #
################################################################################

start_game() {
	
	# Launch process
	echo
	echo "### Starting game"
	cd ${BARRICADE_DIR}
	CMD="${JAVA} -jar ${BARRICADE_JAR}"
	echo
	echo "### Launching game using the following command line:"
	echo "${CMD}"
	${CMD} &
}

################################################################################
# Main script entry                                                            #
################################################################################

start_game

exit 0
